@@ -20,10 +20,7 @@ def query(
 ):
     dataconnect_client = get_dataconnect_client(dataconnect_url)
 
-    try:
-        results = dataconnect_client.search_table(q)
-    except:
-        sys.exit(1)
+    results = dataconnect_client.search_table(q)
 
     if format == "csv":
         output = format_query_result_as_csv(
@@ -46,11 +43,7 @@ def query(
 def list_tables(dataconnect_url):
     dataconnect_client = get_dataconnect_client(dataconnect_url)
 
-    try:
-        tables_iterator = dataconnect_client.get_table_list()
-    except HTTPError:
-        click.echo(HTTPError.response)
-        sys.exit(1)
+    tables_iterator = dataconnect_client.get_table_list()
 
     return json.dumps(
         list(handle_client_results(tables_iterator, dataconnect_url)), indent=4
@@ -60,19 +53,7 @@ def list_tables(dataconnect_url):
 def get_table(dataconnect_url, table_name):
     dataconnect_client = get_dataconnect_client(dataconnect_url)
 
-    try:
-        table_info = dataconnect_client.get_table_info(table_name)
-    except SSLError:
-        click.secho(
-            f"Unable to retrieve SSL certificate from {dataconnect_url}", fg="red"
-        )
-        sys.exit(1)
-    except HTTPError as error:
-        if "404" in str(error.response):
-            click.secho(f"Invalid table name: {table_name}.", fg="red")
-        else:
-            click.echo(error.response)
-        sys.exit(1)
+    table_info = dataconnect_client.get_table_info(table_name)
 
     # formatting response to remove unnecessary fields
     results = table_info.to_dict()
