@@ -50,8 +50,10 @@ class PublisherClient:
             )
 
         def query(self, collection_name, query):
-            return collections_client.query(
-                self.parent.collections_url, collection_name, query
+            return json.loads(
+                collections_client.query(
+                    self.parent.collections_url, collection_name, query
+                )
             )
 
     def load(self, urls, output_dir=downloads_directory):
